pub enum ErofsRequest {
Serve {
payload: ErofsServeRequest,
responder: ErofsServeResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: ErofsControlHandle,
method_type: MethodType,
},
}Expand description
Manage erofs instances.
Variants
Serve
Serves a new erofs instance, on a backing_vmo which contains the contents of the filesystem. If there is an error setting up the initial connection it will be returned and the directory connection will be closed.
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: ErofsControlHandle
method_type: MethodTypeImplementations
Sourceimpl ErofsRequest
impl ErofsRequest
pub fn into_serve(self) -> Option<(ErofsServeRequest, ErofsServeResponder)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL