pub struct ErofsMarker;Trait Implementations
Sourceimpl Clone for ErofsMarker
impl Clone for ErofsMarker
Sourcefn clone(&self) -> ErofsMarker
fn clone(&self) -> ErofsMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ErofsMarker
impl Debug for ErofsMarker
Sourceimpl DiscoverableProtocolMarker for ErofsMarker
impl DiscoverableProtocolMarker for ErofsMarker
Sourceconst PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
const PROTOCOL_NAME: &'static str = <Self as ProtocolMarker>::DEBUG_NAME
The name of the protocol (to be used for service lookup and discovery).
Sourceimpl Hash for ErofsMarker
impl Hash for ErofsMarker
Sourceimpl Ord for ErofsMarker
impl Ord for ErofsMarker
Sourcefn cmp(&self, other: &ErofsMarker) -> Ordering
fn cmp(&self, other: &ErofsMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ErofsMarker
impl PartialEq for ErofsMarker
Sourcefn eq(&self, other: &ErofsMarker) -> bool
fn eq(&self, other: &ErofsMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ErofsMarker
impl PartialOrd for ErofsMarker
Sourceimpl ProtocolMarker for ErofsMarker
impl ProtocolMarker for ErofsMarker
Sourceconst DEBUG_NAME: &'static str = "fuchsia.erofs.Erofs"
const DEBUG_NAME: &'static str = "fuchsia.erofs.Erofs"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = ErofsProxy
type Proxy = ErofsProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = ErofsRequestStream
type RequestStream = ErofsRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = ErofsSynchronousProxy
type SynchronousProxy = ErofsSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for ErofsMarker
impl Eq for ErofsMarker
impl StructuralPartialEq for ErofsMarker