pub struct ErofsProxy { /* private fields */ }Implementations
Sourceimpl ErofsProxy
impl ErofsProxy
Sourcepub fn take_event_stream(&self) -> ErofsEventStream
pub fn take_event_stream(&self) -> ErofsEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn serve(
&self,
payload: ErofsServeRequest,
) -> QueryResponseFut<ErofsServeResult, DefaultFuchsiaResourceDialect>
pub fn serve( &self, payload: ErofsServeRequest, ) -> QueryResponseFut<ErofsServeResult, DefaultFuchsiaResourceDialect>
Serves a new erofs instance, on a backing_vmo which contains the contents of the filesystem. If there is an error setting up the initial connection it will be returned and the directory connection will be closed.