pub struct ErofsServeRequest {
pub backing_vmo: Option<Vmo>,
pub root: Option<ServerEnd<DirectoryMarker>>,
/* private fields */
}Fields
backing_vmo: Option<Vmo>The vmo with the contents of the erofs instance to serve. Erofs is read-only so the vmo contents will not be modified.
root: Option<ServerEnd<DirectoryMarker>>The server end of an initial directory connection to the root of the new filesystem. This directory connection will only have read rights.