pub struct ErofsSynchronousProxy { /* private fields */ }Implementations
Sourceimpl ErofsSynchronousProxy
impl ErofsSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<ErofsEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<ErofsEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn serve(
&self,
payload: ErofsServeRequest,
___deadline: MonotonicInstant,
) -> Result<ErofsServeResult, Error>
pub fn serve( &self, payload: ErofsServeRequest, ___deadline: MonotonicInstant, ) -> Result<ErofsServeResult, Error>
Serves a new erofs instance, on a backing_vmo which contains the contents of the filesystem. If there is an error setting up the initial connection it will be returned and the directory connection will be closed.